Plot Raw Values, Moving Average, and Monotonized Moving Average
plotCutsIDM.RdVisualizes the IDM rating process for each rater, showing raw ratings, smoothed moving averages, and the final isotonic regression line used to determine cut scores.
Arguments
- res_list
A list returned by
computeCutsIDM()containing the processed data and cut score coordinates.- est_col
Optional character scalar. Label to use for the item difficulty axis. If
NULL, the value stored bycomputeCutsIDM()is used.